@@ -3,10 +3,10 @@
  *  Module    : bugrep.h
  *  Author    : Urs Janssen <urs@tin.org>
  *  Created   : 1997-07-30
- *  Updated   : 2003-09-19
+ *  Updated   : 2006-02-15
  *  Notes     :
  *
- * Copyright (c) 1997-2006 Urs Janssen <urs@tin.org>
+ * Copyright (c) 1997-2011 Urs Janssen <urs@tin.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,10 +42,6 @@
 #		define BUG_REPORT_ADDRESS	"tin-bugs@tin.org"
 #	endif /* M_UNIX */
 
-#	ifdef VMS
-#		define BUG_REPORT_ADDRESS	"stenns@vw.tci.uni-hannover.de"
-#	endif /* VMS */
-
 /* fallback */
 #	ifndef BUG_REPORT_ADDRESS
 #		define BUG_REPORT_ADDRESS	"tin-bugs@tin.org"
