@@ -3,10 +3,10 @@
  *  Module    : options_menu.c
  *  Author    : Michael Bienia <michael@vorlon.ping.de>
  *  Created   : 2004-09-05
- *  Updated   : 2010-10-29
+ *  Updated   : 2011-05-14
  *  Notes     : Split from config.c
  *
- * Copyright (c) 2004-2010 Michael Bienia <michael@vorlon.ping.de>
+ * Copyright (c) 2004-2011 Michael Bienia <michael@vorlon.ping.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -228,6 +228,11 @@ option_is_visible(
 		case OPT_UNDERSCORES_REGEX:
 			return curr_scope ? FALSE : tinrc.word_highlight;
 
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+		case OPT_UTF8_GRAPHICS:
+			return curr_scope ? FALSE : IS_LOCAL_CHARSET("UTF-8");
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+
 		case OPT_VERBATIM_BEGIN_REGEX:
 		case OPT_VERBATIM_END_REGEX:
 			return curr_scope ? FALSE : tinrc.verbatim_handling;
@@ -245,16 +250,6 @@ option_is_visible(
 		case OPT_EXPERT_OPTIONS:
 			return TRUE;
 
-		case OPT_ATTRIB_QUICK_KILL_HEADER:
-		case OPT_ATTRIB_QUICK_KILL_SCOPE:
-		case OPT_ATTRIB_QUICK_KILL_EXPIRE:
-		case OPT_ATTRIB_QUICK_KILL_CASE:
-		case OPT_ATTRIB_QUICK_SELECT_HEADER:
-		case OPT_ATTRIB_QUICK_SELECT_SCOPE:
-		case OPT_ATTRIB_QUICK_SELECT_EXPIRE:
-		case OPT_ATTRIB_QUICK_SELECT_CASE:
-			return FALSE;
-
 		case OPT_ATTRIB_ADD_POSTED_TO_FILTER:
 		case OPT_ATTRIB_ADVERTISING:
 		case OPT_ATTRIB_ALTERNATIVE_HANDLING:
@@ -290,6 +285,14 @@ option_is_visible(
 		case OPT_ATTRIB_POST_MIME_ENCODING:
 		case OPT_ATTRIB_POST_PROCESS_VIEW:
 		case OPT_ATTRIB_POS_FIRST_UNREAD:
+		case OPT_ATTRIB_QUICK_KILL_HEADER:
+		case OPT_ATTRIB_QUICK_KILL_SCOPE:
+		case OPT_ATTRIB_QUICK_KILL_EXPIRE:
+		case OPT_ATTRIB_QUICK_KILL_CASE:
+		case OPT_ATTRIB_QUICK_SELECT_HEADER:
+		case OPT_ATTRIB_QUICK_SELECT_SCOPE:
+		case OPT_ATTRIB_QUICK_SELECT_EXPIRE:
+		case OPT_ATTRIB_QUICK_SELECT_CASE:
 #ifndef DISABLE_PRINTING
 		case OPT_ATTRIB_PRINT_HEADER:
 #endif /* !DISABLE_PRINTING */
@@ -544,7 +547,7 @@ move_cursor(
 			if (cur_option < first_option_on_screen) {
 				/* move the markers one option up */
 				first_option_on_screen = cur_option;
-				last_option_on_screen = prev_option(last_option_on_screen, TRUE);
+				set_last_option_on_screen(cur_option);
 #ifdef USE_CURSES
 				do_scroll(-1);
 				print_any_option(cur_option);
@@ -769,8 +772,6 @@ static void
 redraw_screen(
 	enum option_enum option)
 {
-	my_retouch();
-	set_xclick_off();
 	show_config_page();
 	highlight_option(option);
 }
@@ -920,6 +921,8 @@ config_page(
 	set_last_option_on_screen(0);
 
 	redraw_screen(option);
+	set_xclick_off();
+
 	forever {
 		switch ((func = handle_keypad(option_left, option_right, NULL, option_menu_keys))) {
 			case GLOBAL_QUIT:
@@ -1205,6 +1208,8 @@ config_page(
 				break;
 
 			case GLOBAL_REDRAW_SCREEN:
+				my_retouch();
+				set_xclick_off();
 				set_last_option_on_screen(first_option_on_screen);
 				redraw_screen(option);
 				break;
@@ -1235,6 +1240,9 @@ config_page(
 						case OPT_TRANSLIT:
 #endif /* HAVE_ICONV_OPEN_TRANSLIT && CHARSET_CONVERSION */
 						case OPT_UNLINK_ARTICLE:
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+						case OPT_UTF8_GRAPHICS:
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 						case OPT_URL_HIGHLIGHT:
 #ifdef HAVE_KEYPAD
 						case OPT_USE_KEYPAD:
@@ -1577,6 +1585,26 @@ config_page(
 								SET_NUM_ATTRIBUTE(prompt_followupto);
 							break;
 
+						case OPT_ATTRIB_QUICK_KILL_CASE:
+							if (prompt_option_on_off(option))
+								SET_NUM_ATTRIBUTE(quick_kill_case);
+							break;
+
+						case OPT_ATTRIB_QUICK_KILL_EXPIRE:
+							if (prompt_option_on_off(option))
+								SET_NUM_ATTRIBUTE(quick_kill_expire);
+							break;
+
+						case OPT_ATTRIB_QUICK_SELECT_CASE:
+							if (prompt_option_on_off(option))
+								SET_NUM_ATTRIBUTE(quick_select_case);
+							break;
+
+						case OPT_ATTRIB_QUICK_SELECT_EXPIRE:
+							if (prompt_option_on_off(option))
+								SET_NUM_ATTRIBUTE(quick_select_expire);
+							break;
+
 						case OPT_ATTRIB_SHOW_ONLY_UNREAD_ARTS:
 							if (prompt_option_on_off(option))
 								SET_NUM_ATTRIBUTE(show_only_unread_arts);
@@ -1635,7 +1663,6 @@ config_page(
 				case OPT_LIST:
 					switch (option) {
 #ifdef HAVE_COLOR
-						case OPT_COL_BACK:
 						case OPT_COL_FROM:
 						case OPT_COL_HEAD:
 						case OPT_COL_HELP:
@@ -1644,7 +1671,6 @@ config_page(
 						case OPT_COL_MESSAGE:
 						case OPT_COL_MINIHELP:
 						case OPT_COL_NEWSHEADERS:
-						case OPT_COL_NORMAL:
 						case OPT_COL_QUOTE:
 						case OPT_COL_QUOTE2:
 						case OPT_COL_QUOTE3:
@@ -1680,6 +1706,14 @@ config_page(
 							prompt_option_list(option);
 							break;
 
+#ifdef HAVE_COLOR
+						case OPT_COL_BACK:
+						case OPT_COL_NORMAL:
+							if (prompt_option_list(option))
+								redraw_screen(option);
+							break;
+#endif /* HAVE_COLOR */
+
 						case OPT_AUTO_CC_BCC:
 							if (prompt_option_list(option))
 								UPDATE_INT_ATTRIBUTES(auto_cc_bcc);
@@ -1874,6 +1908,16 @@ config_page(
 								SET_NUM_ATTRIBUTE(post_process_type);
 							break;
 
+						case OPT_ATTRIB_QUICK_KILL_HEADER:
+							if (prompt_option_list(option))
+								SET_NUM_ATTRIBUTE(quick_kill_header);
+							break;
+
+						case OPT_ATTRIB_QUICK_SELECT_HEADER:
+							if (prompt_option_list(option))
+								SET_NUM_ATTRIBUTE(quick_select_header);
+							break;
+
 						case OPT_ATTRIB_SHOW_AUTHOR:
 							if (prompt_option_list(option))
 								SET_NUM_ATTRIBUTE(show_author);
@@ -2183,6 +2227,16 @@ config_page(
 								SET_STRING_ATTRIBUTE(organization);
 							break;
 
+						case OPT_ATTRIB_QUICK_KILL_SCOPE:
+							if (prompt_option_string(option))
+								SET_STRING_ATTRIBUTE(quick_kill_scope);
+							break;
+
+						case OPT_ATTRIB_QUICK_SELECT_SCOPE:
+							if (prompt_option_string(option))
+								SET_STRING_ATTRIBUTE(quick_select_scope);
+							break;
+
 						case OPT_ATTRIB_QUOTE_CHARS:
 							if (prompt_option_string(option))
 								SET_STRING_ATTRIBUTE(quote_chars);
@@ -2444,6 +2498,7 @@ scope_page(
 
 			case GLOBAL_REDRAW_SCREEN:
 				my_retouch();
+				set_xclick_off();
 				show_scope_page();
 				break;
 
@@ -2856,6 +2911,22 @@ check_state(
 			return curr_scope->state->process_only_unread;
 		case OPT_ATTRIB_PROMPT_FOLLOWUPTO:
 			return curr_scope->state->prompt_followupto;
+		case OPT_ATTRIB_QUICK_KILL_SCOPE:
+			return curr_scope->state->quick_kill_scope;
+		case OPT_ATTRIB_QUICK_KILL_HEADER:
+			return curr_scope->state->quick_kill_header;
+		case OPT_ATTRIB_QUICK_KILL_CASE:
+			return curr_scope->state->quick_kill_case;
+		case OPT_ATTRIB_QUICK_KILL_EXPIRE:
+			return curr_scope->state->quick_kill_expire;
+		case OPT_ATTRIB_QUICK_SELECT_SCOPE:
+			return curr_scope->state->quick_select_scope;
+		case OPT_ATTRIB_QUICK_SELECT_HEADER:
+			return curr_scope->state->quick_select_header;
+		case OPT_ATTRIB_QUICK_SELECT_CASE:
+			return curr_scope->state->quick_select_case;
+		case OPT_ATTRIB_QUICK_SELECT_EXPIRE:
+			return curr_scope->state->quick_select_expire;
 		case OPT_ATTRIB_QUOTE_CHARS:
 			return curr_scope->state->quote_chars;
 		case OPT_ATTRIB_SAVEDIR:
@@ -3051,6 +3122,40 @@ reset_state(
 			curr_scope->state->news_headers_to_not_display = FALSE;
 			snprintf(tinrc.attrib_news_headers_to_not_display, sizeof(tinrc.attrib_news_headers_to_not_display), "%s", BlankIfNull(default_scope->attribute->news_headers_to_not_display));
 			break;
+		case OPT_ATTRIB_QUICK_KILL_SCOPE:
+			FreeAndNull(curr_scope->attribute->quick_kill_scope);
+			curr_scope->state->quick_kill_scope = FALSE;
+			snprintf(tinrc.attrib_quick_kill_scope, sizeof(tinrc.attrib_quick_kill_scope), "%s", BlankIfNull(default_scope->attribute->quick_kill_scope));
+			break;
+		case OPT_ATTRIB_QUICK_KILL_HEADER:
+			curr_scope->state->quick_kill_header = FALSE;
+			tinrc.attrib_quick_kill_header = default_scope->attribute->quick_kill_header;
+			break;
+		case OPT_ATTRIB_QUICK_KILL_CASE:
+			curr_scope->state->quick_kill_case = FALSE;
+			tinrc.attrib_quick_kill_case = default_scope->attribute->quick_kill_case;
+			break;
+		case OPT_ATTRIB_QUICK_KILL_EXPIRE:
+			curr_scope->state->quick_kill_expire = FALSE;
+			tinrc.attrib_quick_kill_expire = default_scope->attribute->quick_kill_expire;
+			break;
+		case OPT_ATTRIB_QUICK_SELECT_SCOPE:
+			FreeAndNull(curr_scope->attribute->quick_select_scope);
+			curr_scope->state->quick_select_scope = FALSE;
+			snprintf(tinrc.attrib_quick_select_scope, sizeof(tinrc.attrib_quick_select_scope), "%s", BlankIfNull(default_scope->attribute->quick_select_scope));
+			break;
+		case OPT_ATTRIB_QUICK_SELECT_HEADER:
+			curr_scope->state->quick_select_header = FALSE;
+			tinrc.attrib_quick_select_header = default_scope->attribute->quick_select_header;
+			break;
+		case OPT_ATTRIB_QUICK_SELECT_CASE:
+			curr_scope->state->quick_select_case = FALSE;
+			tinrc.attrib_quick_select_case = default_scope->attribute->quick_select_case;
+			break;
+		case OPT_ATTRIB_QUICK_SELECT_EXPIRE:
+			curr_scope->state->quick_select_expire = FALSE;
+			tinrc.attrib_quick_select_expire = default_scope->attribute->quick_select_expire;
+			break;
 		case OPT_ATTRIB_NEWS_QUOTE_FORMAT:
 			FreeAndNull(curr_scope->attribute->news_quote_format);
 			curr_scope->state->news_quote_format = FALSE;
@@ -3255,6 +3360,12 @@ initialize_attributes(
 #endif /* !DISABLE_PRINTING */
 	INITIALIZE_NUM_ATTRIBUTE(process_only_unread);
 	INITIALIZE_NUM_ATTRIBUTE(prompt_followupto);
+	INITIALIZE_NUM_ATTRIBUTE(quick_kill_header);
+	INITIALIZE_NUM_ATTRIBUTE(quick_kill_case);
+	INITIALIZE_NUM_ATTRIBUTE(quick_kill_expire);
+	INITIALIZE_NUM_ATTRIBUTE(quick_select_header);
+	INITIALIZE_NUM_ATTRIBUTE(quick_select_case);
+	INITIALIZE_NUM_ATTRIBUTE(quick_select_expire);
 	INITIALIZE_NUM_ATTRIBUTE(show_author);
 	INITIALIZE_NUM_ATTRIBUTE(show_info);
 	INITIALIZE_NUM_ATTRIBUTE(show_only_unread_arts);
@@ -3288,6 +3399,8 @@ initialize_attributes(
 	INITIALIZE_STRING_ATTRIBUTE(news_headers_to_not_display);
 	INITIALIZE_STRING_ATTRIBUTE(news_quote_format);
 	INITIALIZE_STRING_ATTRIBUTE(organization);
+	INITIALIZE_STRING_ATTRIBUTE(quick_kill_scope);
+	INITIALIZE_STRING_ATTRIBUTE(quick_select_scope);
 	INITIALIZE_STRING_ATTRIBUTE(quote_chars);
 	INITIALIZE_STRING_ATTRIBUTE(savedir);
 	INITIALIZE_STRING_ATTRIBUTE(savefile);
