@@ -3,10 +3,10 @@
  *  Module    : rfc2047.c
  *  Author    : Chris Blum <chris@resolution.de>
  *  Created   : 1995-09-01
- *  Updated   : 2010-03-17
+ *  Updated   : 2010-09-15
  *  Notes     : MIME header encoding/decoding stuff
  *
- * Copyright (c) 1995-2010 Chris Blum <chris@resolution.de>
+ * Copyright (c) 1995-2011 Chris Blum <chris@resolution.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -378,7 +378,7 @@ do_b_encode(
 	t_bool isleading_between = TRUE;		/* are we still processing leading space */
 
 	while (count-- > 0 && (!isbetween(*w, isstruct_head) || isleading_between) && *w) {
-		len8 += is_EIGHT_BIT(w) ? 1 : (-len8);
+		len8 += (is_EIGHT_BIT(w) ? 1 : -len8);
 		if (!isbetween(*w, isstruct_head))
 			isleading_between = FALSE;
 		*(t++) = *(w++);
@@ -597,7 +597,7 @@ rfc1522_do_encode(
 #endif /* 0 */
 					{
 						snprintf(buf2, sizeof(buf2), "=%2.2X", *EIGHT_BIT(what));
-						if ((size_t)( t - buffer + 3) >= bufferlen) {
+						if ((size_t)(t - buffer + 3) >= bufferlen) {
 							/* buffer too small, double its size */
 							offset = t - buffer;
 							bufferlen <<= 1;
@@ -1197,8 +1197,11 @@ compose_mail_mime_forwarded(
 	}
 
 	/* Put it all together */
-	if ((fp = fopen(filename, "w")) == NULL)
+	if ((fp = fopen(filename, "w")) == NULL) {
+		fclose(headerfp);
+		fclose(entityfp);
 		return;
+	}
 
 	rewind(headerfp);
 	while ((line = tin_fgets(headerfp, TRUE))) {
@@ -1319,7 +1322,7 @@ contains_8bit_characters(
 
 	rewind(fp);
 	while ((line = tin_fgets(fp, FALSE))) {
-		for ( ; *line != '\0'; line++) {
+		for (; *line != '\0'; line++) {
 			if (is_EIGHT_BIT(line))
 				return TRUE;
 		}
