@@ -3,11 +3,11 @@
  *  Module    : tcurses.c
  *  Author    : Thomas Dickey <dickey@invisible-island.net>
  *  Created   : 1997-03-02
- *  Updated   : 2009-10-22
+ *  Updated   : 2011-04-17
  *  Notes     : This is a set of wrapper functions adapting the termcap
  *	             interface of tin to use SVr4 curses (e.g., ncurses).
  *
- * Copyright (c) 1997-2010 Thomas Dickey <dickey@invisible-island.net>
+ * Copyright (c) 1997-2011 Thomas Dickey <dickey@invisible-island.net>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -139,11 +139,12 @@ InitScreen(
 			bcol(default_bcol = -1);
 		}
 #		endif /* HAVE_USE_DEFAULT_COLORS */
+		postinit_colors(MAX(COLORS, MAX_COLOR + 1)); /* postinit_colors(COLORS) would be correct */
 	} else {
 		use_color = FALSE;
+		postinit_colors(MAX_COLOR + 1);
 	}
 
-	postinit_colors();
 #	endif /* HAVE_COLOR */
 	set_xclick_on();
 	return TRUE;
@@ -396,8 +397,8 @@ highlight_string(
 	tmp[size] = '\0';
 	StartInverse();
 	my_fputs(tmp, stdout);
-	my_flush();
 	EndInverse();
+	my_flush();
 	stow_cursor();
 }
 
@@ -828,6 +829,10 @@ my_retouch(
 	TRACE(("my_retouch"));
 	if (!cmd_line) {
 		wrefresh(curscr);
+#	ifdef HAVE_COLOR
+		fcol(tinrc.col_normal);
+		bcol(tinrc.col_back);
+#	endif /* HAVE_COLOR */
 	}
 }
 
